GPU Context representation.
A Buffer representation.
A program that clears colors, depth and stencil of a framebuffer.
A builder for Context.
A fragment shader representation.
A Framebuffer representation with optional color, depth and stencil attachments.
A structure representing a GPU program.
A program for rasterizing VertexArrayObjects in a target Framebuffer.
Renderbuffer representation.
A Sampler is responsible for sampling values from a texture. It supports filtering and coordinates wrapping.
A shader representation.
A Texture representation.
A Texture2D representation.
A Texture3D representation.
Texture format representation with color format and component format.
VertexArrayObject representation.
A vertex shader representation.