pub struct ClearProgram { /* private fields */ }Expand description
A program that clears colors, depth and stencil of a framebuffer.
Implementations
Sourceimpl ClearProgram
impl ClearProgram
Sourcepub fn set_stencil(&mut self, stencil: i32)
pub fn set_stencil(&mut self, stencil: i32)
Sets the stencil clear value.
Sourcepub fn clear(&self, framebuffer: &mut Framebuffer, clear_mask: u32)
pub fn clear(&self, framebuffer: &mut Framebuffer, clear_mask: u32)
Clear the target Framebuffer using the buffer bit mask.
Here is an example that clears color, depth and stencil in a single call:
ⓘ
clear(framebuffer, ClearProgram::COLOR | ClearProgram::DEPTH | ClearProgram::STENCIL)Auto Trait Implementations
impl !Send for ClearProgram
impl !Sync for ClearProgram
impl Freeze for ClearProgram
impl RefUnwindSafe for ClearProgram
impl Unpin for ClearProgram
impl UnsafeUnpin for ClearProgram
impl UnwindSafe for ClearProgram